pub struct FtpResponse {
pub code: u16,
pub message: String,
}Expand description
FTP server response with code and message
Fields
code: u16message: StringImplementations
Sourceimpl FtpResponse
impl FtpResponse
pub fn is_success(&self) -> bool
pub fn is_intermediate(&self) -> bool
pub fn is_positive_completion(&self) -> bool
pub fn is_positive_preliminary(&self) -> bool
Sourcepub fn class(&self) -> FtpResponseClass
pub fn class(&self) -> FtpResponseClass
Get the response class for this response
Sourcepub fn is_transient_error(&self) -> bool
pub fn is_transient_error(&self) -> bool
Check if this response indicates a transient error (retry-worthy)
Sourcepub fn is_permanent_error(&self) -> bool
pub fn is_permanent_error(&self) -> bool
Check if this response indicates a permanent error (do not retry)